Netabase Dependencies
This crate provides hygienic re-exports of all dependencies used by the Netabase macros. It ensures that procedural macros can reference external dependencies without requiring users to manually import them.
This crate is an implementation detail and should not be used directly by end users.
Re-exports
pub use bincode;pub use blake3;pub use derive_more;pub use libp2p;pub use serde;pub use sled;pub use strum;pub use uniffi;
Modules
- __
private - Re-exports of all dependencies used by generated macro code. This ensures macro hygiene - users don’t need to manually import these dependencies.